==> gnome-media-2.30.0-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/gnome-audio-profiles/sv/figures ; rm -rf gnome-audio-profiles-profiles-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/sv/figures ; ln -sf ../../C/figures/gnome-audio-profiles-profiles-window.png gnome-audio-profiles-profiles-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/es/figures ; rm -rf gnome-audio-profiles-profile-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/es/figures ; ln -sf ../../C/figures/gnome-audio-profiles-profile-window.png gnome-audio-profiles-profile-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/es/figures ; rm -rf gnome-audio-profiles-profiles-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/es/figures ; ln -sf ../../C/figures/gnome-audio-profiles-profiles-window.png gnome-audio-profiles-profiles-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/el/figures ; rm -rf gnome-audio-profiles-profile-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/el/figures ; ln -sf ../../C/figures/gnome-audio-profiles-profile-window.png gnome-audio-profiles-profile-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/el/figures ; rm -rf gnome-audio-profiles-profiles-window.png )
( cd usr/share/gnome/help/gnome-audio-profiles/el/figures ; ln -sf ../../C/figures/gnome-audio-profiles-profiles-window.png gnome-audio-profiles-profiles-window.png )
( cd usr/share/gnome/help/gnome-volume-control/en_GB/figures ; rm -rf gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/en_GB/figures ; ln -sf ../../C/figures/gnome-volume-control_window.png gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/zh_CN/figures ; rm -rf gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/zh_CN/figures ; ln -sf ../../C/figures/gnome-volume-control_window.png gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/cs/figures ; rm -rf gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/cs/figures ; ln -sf ../../C/figures/gnome-volume-control_window.png gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/el/figures ; rm -rf gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/el/figures ; ln -sf ../../C/figures/gnome-volume-control_window.png gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/oc/figures ; rm -rf gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/oc/figures ; ln -sf ../../C/figures/gnome-volume-control_window.png gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/ru/figures ; rm -rf gnome-volume-control_window.png )
( cd usr/share/gnome/help/gnome-volume-control/ru/figures ; ln -sf ../../C/figures/gnome-volume-control_window.png gnome-volume-control_window.png )
( cd usr/share/gnome/help/gstreamer-properties/en_GB/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/en_GB/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/zh_CN/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/zh_CN/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/pt_BR/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/pt_BR/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/el/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/el/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/oc/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/oc/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/ru/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/ru/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/en_GB/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/en_GB/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/zh_CN/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/zh_CN/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/oc/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/oc/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/da/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/da/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/ru/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/ru/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/lib64 ; rm -rf libgnome-media-profiles.so.0 )
( cd usr/lib64 ; ln -sf libgnome-media-profiles.so.0.0.0 libgnome-media-profiles.so.0 )
( cd usr/lib64 ; rm -rf libgnome-media-profiles.so )
( cd usr/lib64 ; ln -sf libgnome-media-profiles.so.0.0.0 libgnome-media-profiles.so )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/gnome-audio-profiles.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/gnome-sound-recorder.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/gnome-volume-control.schemas >/dev/null 2>&1
fi
# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor 1>/dev/null 2>/dev/null

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> gnome-media-2.91.2-x86_64-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/gnome-sound-recorder/sl/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/sl/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/oc/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/oc/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/ru/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/ru/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/zh_CN/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/zh_CN/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/da/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/da/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/en_GB/figures ; rm -rf grecord_window.png )
( cd usr/share/gnome/help/gnome-sound-recorder/en_GB/figures ; ln -sf ../../C/figures/grecord_window.png grecord_window.png )
( cd usr/share/gnome/help/gstreamer-properties/el/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/el/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/sl/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/sl/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/oc/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/oc/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/pt_BR/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/pt_BR/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/ru/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/ru/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/gl/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/gl/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/da/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/da/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/en_GB/figures ; rm -rf gstreamer_properties_window.png )
( cd usr/share/gnome/help/gstreamer-properties/en_GB/figures ; ln -sf ../../C/figures/gstreamer_properties_window.png gstreamer_properties_window.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/gnome-sound-recorder.schemas >/dev/null 2>&1
fi
# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor 1>/dev/null 2>/dev/null
